@@ -1,8 +1,8 @@
-use std::{ process::Command, path::PathBuf };
-use std::io::{ Error, ErrorKind, Write };
+use std::io::{Error, ErrorKind, Write};
+use std::{path::Path, process::Command};
 
 pub fn execute(command: &str, arguments: Option<Vec<&str>>) -> Result<(), Error> {
-    let mut exe = Command::new(&command);
+    let mut exe = Command::new(command);
 
     if let Some(args) = arguments {
         exe.args(args);
@@ -24,9 +24,9 @@ pub fn execute(command: &str, arguments: Option<Vec<&str>>) -> Result<(), Error>
     }
 }
 
-pub fn undivert(file: &PathBuf) -> Result<(), Error> {
+pub fn undivert(file: &Path) -> Result<(), Error> {
     let orig = format!("{}", file.display());
-    let args = vec!["--package", "droid-juicer", "--rename", "--remove", &orig ];
+    let args = vec!["--package", "droid-juicer", "--rename", "--remove", &orig];
 
     execute("/usr/bin/dpkg-divert", Some(args))
 }
